import type { ComponentProps } from '@fluentui/react-utilities';
import type { ComponentState } from '@fluentui/react-utilities';
import type { ForwardRefComponent } from '@fluentui/react-utilities';
import * as React_2 from 'react';
import type { Slot } from '@fluentui/react-utilities';

/**
 * The Container helps position and handle padding for an application's layout.
 */
export declare const Container: ForwardRefComponent<ContainerProps>;

export declare interface ContainerCommons {
    /**
     * The appearance of the Container.
     * Focused has a lower padding and gap size then relaxed.
     * Relaxed should be used when the content of your app is minimal.
     *
     * @defaultValue focused
     */
    appearance?: 'focused' | 'relaxed';
    /**
     * How the content should be aligned horizontally.
     */
    horizontalAlignment?: 'start' | 'center' | 'end';
    /**
     * How the content should be aligned vertically.
     */
    verticalAlignment?: 'start' | 'center' | 'end';
    /**
     * Whether the Container should wrap children content if it's fixed size is reached.
     */
    wrap?: boolean;
}

export declare type ContainerProps = ComponentProps<ContainerSlots> & ContainerCommons;

export declare type ContainerSlots = {
    /**
     * The root of the Container.
     */
    root: Slot<'div'>;
};

export declare type ContainerState = ComponentState<ContainerSlots> & ContainerCommons;

/**
 * The Stack helps position and handle padding for a series of components.
 */
export declare const Stack: ForwardRefComponent<StackProps>;

export declare interface StackCommons {
    /**
     * Whether the stack should be rendered vertically.
     *
     * @defaultValue true
     */
    vertical?: boolean;
    /**
     * The divider to render between each child element.
     */
    divider?: React_2.ReactNode;
    /**
     * The appearance of the Stack.
     * Focused has a lower padding and gap size then relaxed.
     * Relaxed should be used when the content of your app is minimal.
     *
     * @defaultValue focused
     */
    appearance?: 'focused' | 'relaxed';
    /**
     * How the components should be aligned horizontally.
     */
    horizontalAlignment?: 'start' | 'center' | 'end';
    /**
     * How the component should be aligned vertically.
     */
    verticalAlignment?: 'start' | 'center' | 'end';
    /**
     * Whether the content should be inline. This will cause the content to grow based on its children's size rather than parent.
     */
    inline?: boolean;
    /**
     * Whether the content should wrap.
     */
    wrap?: boolean;
    /**
     * Whether the Stack should grow to fit its container.
     */
    grow?: boolean;
}

export declare type StackProps = ComponentProps<StackSlots> & StackCommons;

export declare type StackSlots = {
    /**
     * The root of the Stack.
     */
    root: Slot<'div'>;
};

export declare type StackState = ComponentState<StackSlots> & StackCommons;

export declare const useContainer: (props: ContainerProps, ref: React_2.Ref<HTMLElement>) => ContainerState;

export declare const useContainerStyles: (state: ContainerState) => ContainerState;

export declare const useStack: (props: StackProps, ref: React_2.Ref<HTMLElement>) => StackState;

export declare const useStackStyles: (state: StackState) => StackState;

export { }
