import React from 'react';
import { Stack } from './Stack';
import { isConformant } from '../../common/isConformant';
import { render } from '@testing-library/react';
describe('Input', () => {
    isConformant({
        Component: Stack,
        displayName: 'Stack',
    });
    it('renders a basic Stack', () => {
        const renderedComponent = render(React.createElement(Stack, null));
        expect(renderedComponent.baseElement).toMatchSnapshot();
    });
    it('renders a divider Stack', () => {
        const renderedComponent = render(React.createElement(Stack, { divider: ' - ' },
            React.createElement("p", null, "Hello"),
            React.createElement("p", null, "Hello")));
        expect(renderedComponent.baseElement).toMatchSnapshot();
    });
    it('renders a divider Stack with once child', () => {
        const renderedComponent = render(React.createElement(Stack, { divider: ' - ' },
            React.createElement("p", null, "Hello")));
        expect(renderedComponent.baseElement).toMatchSnapshot();
    });
    it('renders a vertical Stack', () => {
        const renderedComponent = render(React.createElement(Stack, { vertical: true }));
        expect(renderedComponent.baseElement).toMatchSnapshot();
    });
    it('Correctly applies horizontal/vertical alignment to Stack (vertical)', () => {
        const renderedComponent = render(React.createElement(Stack, { vertical: true, horizontalAlignment: "center", verticalAlignment: "center" }));
        expect(renderedComponent.baseElement).toMatchSnapshot();
    });
    it('Correctly applies horizontal/vertical alignment to Stack (horizontal)', () => {
        const renderedComponent = render(React.createElement(Stack, { horizontalAlignment: "center", verticalAlignment: "center" }));
        expect(renderedComponent.baseElement).toMatchSnapshot();
    });
});
//# sourceMappingURL=Stack.test.js.map