import * as React from 'react';
import { Container } from '../index';
import { makeStyles, shorthands } from '@griffel/react';
import { tokens } from '@pongo-ui/react-theme';
const useStyles = makeStyles({
    root: {
        display: 'flex',
        flexDirection: 'column',
        ...shorthands.gap('10px'),
    },
    box: {
        display: 'flex',
        flexGrow: 1,
        backgroundColor: tokens.brand,
        width: '10px',
        height: '10px',
    },
    containerBorder: {
        ...shorthands.border('1px', 'solid', tokens.inherit),
    },
    verticalExample: {
        height: '500px',
        ...shorthands.border('1px', 'solid', tokens.inherit),
    },
    smallBorderExample: {
        ...shorthands.border('1px', 'solid', tokens.inherit),
        height: '100px',
    },
    largeBox: {
        backgroundColor: tokens.brand,
        width: '100px',
        height: '100px',
    },
});
export const BasicContainerExample = () => {
    const styles = useStyles();
    return (React.createElement(Container, { className: styles.containerBorder },
        React.createElement("div", { className: styles.box }),
        React.createElement("div", { className: styles.box })));
};
export const RelaxedContainerExample = () => {
    const styles = useStyles();
    return (React.createElement(Container, { className: styles.containerBorder, appearance: "relaxed" },
        React.createElement("div", { className: styles.box }),
        React.createElement("div", { className: styles.box })));
};
export const WrapContainerExample = () => {
    const styles = useStyles();
    return (React.createElement(Container, { className: styles.smallBorderExample, wrap: true, appearance: "relaxed" },
        React.createElement("div", { className: styles.largeBox }),
        React.createElement("div", { className: styles.largeBox })));
};
export const HorizontalAlignmentContainerExample = () => {
    const styles = useStyles();
    return (React.createElement("div", { className: styles.root },
        React.createElement(Container, { className: styles.containerBorder, horizontalAlignment: "start" },
            React.createElement("div", { className: styles.box }),
            React.createElement("div", { className: styles.box })),
        React.createElement(Container, { className: styles.containerBorder, horizontalAlignment: "center" },
            React.createElement("div", { className: styles.box }),
            React.createElement("div", { className: styles.box })),
        React.createElement(Container, { className: styles.containerBorder, horizontalAlignment: "end" },
            React.createElement("div", { className: styles.box }),
            React.createElement("div", { className: styles.box }))));
};
export const VerticalAlignmentContainerExample = () => {
    const styles = useStyles();
    return (React.createElement("div", { className: styles.root },
        React.createElement(Container, { className: styles.verticalExample, verticalAlignment: "start" },
            React.createElement("div", { className: styles.box }),
            React.createElement("div", { className: styles.box })),
        React.createElement(Container, { className: styles.verticalExample, verticalAlignment: "center" },
            React.createElement("div", { className: styles.box }),
            React.createElement("div", { className: styles.box })),
        React.createElement(Container, { className: styles.verticalExample, verticalAlignment: "end" },
            React.createElement("div", { className: styles.box }),
            React.createElement("div", { className: styles.box }))));
};
export default {
    title: 'Components/Container',
    component: Container,
};
//# sourceMappingURL=Container.stories.js.map